#
# spec file for package xfce4-terminal
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2012 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with git
Name:           xfce4-terminal
Version:        1.1.0
Release:        1.1
Summary:        Terminal Emulator for the Xfce Desktop Environment
License:        GPL-2.0-or-later
Group:          System/X11/Terminals
URL:            https://docs.xfce.org/apps/terminal/start
Source0:        https://archive.xfce.org/src/apps/xfce4-terminal/1.1/%{name}-%{version}.tar.bz2
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  utempter-devel
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gio-2.0) >= 2.44.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libpcre2-8) >= 10.00
BuildRequires:  pkgconfig(libxfce4kbd-private-3) >= 4.16.0
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.17.5
BuildRequires:  pkgconfig(libxfconf-0) >= 4.16.0
BuildRequires:  pkgconfig(vte-2.91) >= 0.51.3
Recommends:     %{name}-lang

%description
xfce4-terminal is a lightweight and easy to use terminal emulator for the Xfce
desktop environment. Its major features include a simple configuration
interface, the ability to use multiple tabs with terminals within a single
window, the possibility to have a pseudo-transparent terminal background, and a
compact mode where both the menubar and the window decorations are hidden which
helps to save space on the desktop.

%lang_package

%prep
%setup -q

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-maintainer-mode \
    --with-utempter
%else
%configure \
    --with-utempter
%endif
%make_build

%install
%make_install

# create a list of localized man directories, these need to be owned
(
    printf '%%%%defattr(-,root,root)\n'
    cd '%{buildroot}'
    for dir in ".%{_mandir}/"*; do
        [ -d "${dir}" ] || continue
        case ${dir##*/} in
            man*)   continue ;;
            *)      lang="${dir##*/}"
                    printf "%%%%dir %%%%lang(%%s) %%s\n" "${lang}" "${dir#.}"
                    for subdir in "${dir}/"*; do
                        [ -d "${subdir}" ] || continue
                        printf "%%%%dir %%%%lang(%%s) %%s\n" "${lang}" \
                            "${subdir#.}"
                    done
                    ;;
        esac
    done
) >> %{name}.lang

# Fix name issue with xfce4-terminal-settings desktop file name entries boo#1125146
desktop-file-edit %{buildroot}%{_datadir}/applications/%{name}-settings.desktop --set-name='Xfce Terminal Settings'

%find_lang %{name} --with-man %{?no_lang_C}

%files
%doc AUTHORS HACKING NEWS README.md THANKS
%license COPYING
%{_bindir}/xfce4-terminal
%dir %{_datadir}/xfce4
%{_datadir}/xfce4/terminal
%{_datadir}/icons/hicolor/*/apps/org.xfce.terminal*
%{_datadir}/applications/xfce4-terminal.desktop
%{_datadir}/applications/xfce4-terminal-settings.desktop
%{_mandir}/man1/xfce4-terminal.1*

%files lang -f %{name}.lang

%changelog
* Tue Aug 22 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.1.0
  * Update copyright year
  * Allow passing arguments to custom commands
  * Fully translate strings in unsafe paste dialog
  * window: Properly sync always-show-tabs
  * cleanup: Include gdkx.h in one place
  * preferences: Remove unused class member
  * preferences: Check if channel itself exists instead of check
    property
  * screen: Review image loader memory management
  * image-loader: Review cache management
  * Add keywords to .desktop files (Fixes #50)
  * screen: Take window scaling into account when drawing
    (Fixes #71)
  * Remove obsolete GNOME default-app file (Fixes #109)
  * Add "Open File Manager Here" action (Fixes #133)
  * Properly manage default encoding (Fixes #128)
  * Move general include in private.h
  * dropdown: Disable systray icon on Wayland
  * Fix startup with GDK_BACKEND=x11 (Fixes #177)
  * shortcuts: Restore broken action toggle-menubar
  * shortcuts: Fix non-consumed key event for show-menubar
  * main: Allow GTK to parse its options first (Fixes #216)
  * search: Add missing sanity check
  * Use GLib logging functions and do not translate warnings
  * Remove obsolete CHECK_VERSION()
  * Use g_new() instead of malloc()
  * Fix Xfconf memory management
  * search-dialog: Fix memory leak
  * Remove extra separator at the end of context menu
  * Missing shortcut keys in the standalone preferences dialog
    (Issue #198)
  * Apply 1 suggestion(s) to 1 file(s)
  * Enable kinetic scrolling in VteTerminal
  * Extend --disable-server description wrt. process model
  * Drop obsolete --disable-server translations
  * prefs-dialog: Fix untranslated strings
  * Add sixel support
  * Add icons at missing sizes, clean up SVG metadata
  * build: Fix autoconf warnings
  * build: Add GLib requirement
  * Add accel entries for scrolling pages (Issue #221)
  * Remove documentation for dead anti-aliasing option
  * Make strings translatable (Issue #222)
  * Fix shortcuts-editor include
  * Support hyperlinks (Issue #21)
  * Fix argument type for xfce_shortcuts_editor_new
  * fix background_notify
  * Remove disable-help preference.
  * MR: !51 transitioned to Xfconf (#134)
  * typos in MR !48 fixed
  * Remove all references to terminal-preferences.glade
  * Remove one more mention of terminal-preferences.glade
  * Remove trailing slash
  * Remove terminal-preferences-ui.h from makefile
  * Remove terminal-preferences.glade
  * MR: !48 shortcuts editor embedded into preferences-dialog (#195)
  * MR: !48 preferences-dialog rewritten in C (#195)
  * MR: !46 Change in implementation for TAB accels (#150)
  * Implementation of MiscShiftArrowsToScroll as accelerators.
  * Add PCRE2 build dependency
  * Remove libxfce4ui 4.17 version guards
  * Replace with xfce_gtk_menu_append_separator
  * Tweak toolbar
  * Translation Updates
- "gnome-control-center" support is no longer available; remove the
  corresponding entries from the %%files list
* Tue May 31 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 1.0.4
  * Fixes a regression: URL drag-n-drop adding rubbish characters
    (gxo#apps/xfce4-terminak#196)
* Fri May 13 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.0.3
  * Consume KeyEvents when activating a TAB accelerator.
  * Fix Regression: Scrollbar position setting does not work if you
    start  with a hidden scrollbar (gxo#apps/xfce4-terminal#192)
  * Fix Regression: broken scroll-on-output and change the
    default value (gxo#apps/xfce4-terminal#191)
* Fri Apr 22 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.0.2
  * Fix regression: MiscCycleTabs preference does not work for
    accelerators
  * Russian translation updates
* Fri Apr 15 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.0.1
  * A new hidden preference `DropdownParametersOnce` has been
    introduced to control whether the drop-down window accepts
    command line arguments after creation. With the introduction
    of this preference an older bug was fixed where tabs could be
    added to the drop-down window even though they weren't
    supposed to.
  * Options: --active-tab does not behave properly when adding tabs
    to existing windows.
  * Find dialog does not respond to Return key
    (gxo#apps/xfce4-terminal#176)
  * Dragging a URL from Chromium ends up truncated
    (gxo#apps/xfce4-terminal#180)
  * Toolbar size changes when the window is maximized
    (gxo#apps/xfce4-terminal#181).
  * Unable to create a single window with many tabs through command
    line options (gxo#apps/xfce4-terminal#182).
  * Translation Updates
* Sat Apr  2 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.0.0
  * Replace the deprecated GtkActionEntries with XfceGtkActionEntries
    (gxo#apps/xfce4-terminal#79)
  * Opening a dialog from a drop-down window closes the window
    (gxo#apps/xfce4-terminal#136)
  * Add `Fill` background image style (gxo#apps/xfce4-terminal!23).
  * Improved options parsing (for both short and long forms)
  * Add a menu entry to send signals to the foreground process
    (gxo#apps/xfce4-terminal#59)
  * Fix `keep window open` preference being applied on restart.
  * Rework "--tab" and "--window" behavior (gxo#apps/xfce4-terminal#13)
  * Ignore unused modifiers for scroll wheel zooming
  * Add alternative shortcuts for zooming (gxo#apps/xfce4-terminal#126)
  * Expand scrolled window and make dialog size 70%% of parent
    (gxo#apps/xfce4-terminal!17)
  * Support libxfce4ui XfceTitledDialog new API
  * Update unsafe paste dialog text (gxo#apps/xfce4-terminal#73)
  * Fix paste button focus
  * Replace subtitle by infobar for Unsafe paste dialog
  * Fix the `unsafe paste` dialog to actually paste
  * Update `.gitignore`, HACKING, AUTHORS, COPYRIGHTS
  * Update --preferences, --tab and --window documentation
  * Fix various typos
  * Fix compilation warnings
  * Remove unnecessary function call (gxo#apps/xfce4-terminal!24)
  * Add a "Do not warn me again" checkbox for the "Unsafe Paste"
    dialog (gxo#apps/xfce4-terminal#129)
  * Use GtkScrolledWindow for TerminalScreen and add an
    overlay-scrolling preference (gxo#apps/xfce4-terminal#149)
  * Support the new Shortcuts editor widget
    (requires libxfce4ui 4.17.2 or greater)
  * New preference: Select right click action
  * Improved `scrolling-on-output` behaviour.
  * Unsafe Paste Dialog temporary override (gxo#apps/xfce4-terminal#106)
  * Fix regression: File Menu missing `Close Window` entry
  * Fix regression: Disable Help shortcut does not work
  * Fix regression: go-to accelerators not working on startup
  * Fix regression: Revert accelerator paths to maintain backwards
    compatibility
  * Use the latest .glade file structure
  * Change incorrect reference to ${XDG_CONFIG_DIRS} in man page
    (gxo#apps/xfce4-terminal#47)
  * Change outdated documentation links
  * Use XfceTitledDialog for `Find` (gxo#apps/xfce4-terminal#168)
  * Include '\r' in unsafe-paste checks
  * Update tab accelerators at runtime
  * Consume events that activate accelerator callbacks
    (gxo#apps/xfce4-terminal#159, gxo#apps/xfce4-terminal#153)
  * Center on the active terminal window.
  * Change handling of goto-tab accelerators so they can be changed
    through the editor.
  * Menubar changes size when the window is maximized
    (gxo#apps/xfce4-terminal#156)
  * Context Menu: Revert changes in order and contents introduced by
    the transition to XfceGtkActionEntries
  * Add "Show Window Borders" entry in View menu (it was missing
    in the last 2 dev releases)
  * Revert view menu order (Zoom entries below checkboxes)
  * Fix the visibility flag of the scrollbar
    (gxo#apps/xfce4-terminal#161, could lead to broken themes)
  * Replace GTimeVal with gint64
  * Fix build warnings
  * Update Copyright
  * Translation Updates
* Wed Dec 23 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.8.10
  * Bump libvte, gtk and xfce minimal versions (4.14)
  * Stop using G_SPAWN_CHILD_INHERITS_STDIN spawn flag
  * Updates README.md.
  * Added new stock icons
  * Limit font picker to fixed-size fonts
  * Add gtk-doc as a dependency
  * Do not require connection to generate manpage
  * bxo#16875: Do not add ui.h file in datadir
  * Simplify terminal manpage generation
  * Switch preferences ui file to xdt-csource
  * Switch to README.md and foreign automake mode
  * Do not override clipboard contents
  * Unsafe paste: Support bracketed paste mode
  * Do not select text in Search dialog
  * Add basic GitLab pipeline
  * Translation Updates
* Sun Mar 29 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.8.9.2
  * Allow to create window with 1 line height. One should also disable
    the scrollbar (--hide-scrollbar) to get 1 row window. (bxo#16447)
  * Fix 'Transparency setting ignored when using --color-bg' (bxo#16309)
  * Translation updates
* Fri Dec 27 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.8.9.1
  - Fix "Open terminal here" functionality that was broken in release
    0.8.9 (bxo#16307)
- Changes in version 0.8.9
  - Respect the "Working Directory" setting when opening initial window
    (the current directory was used instead). (bxo#16292)
  - Disable "Paste" actions in read-only mode
  - Point session manager to desktop file. (bxo#16121)
  - Resolve G_TYPE_INSTANCE_GET_PRIVATE deprecation warning
  - Allow to use <Alt> shortcuts when menu mnemonics are disabled.
    (bxo#15989)
  - Fix 'Menubar starts shown when set to hidden in properties'
    (bxo#15979)
  - Fix invalid geometry on Wayland.
  - Fix size increase when the menu is used on Wayland (bxo#13938)
  - Avoid passing null pointer to g_warning()
  - Replace GLib threading functions with their GDK counterparts
  - Fix setting a font via the command line (bxo#15869)
  - Properly apply zoom factor when creating new tab (bxo#15785)
  - Add icons to "Cancel" and "Paste" buttons
  - Fix background color changing when changing focus if "Vary the
    background color for each tab" is enabled (bxo#15740)
  - Revert "Save accelerators map on exit".(bxo#16058)
  - Allow to unset window urgency hint even if "Visual bell" is disabled
    (bxo#15729)
  - Unmaximize drop-down window when hiding it. (bxo#15681)
  - Allow to use --maximize with drop-down windows
  - Search dialog: Make opacity scale unfocusable. This prevents the text
    entry from losing focus when the opacity scale is used.
  - Fix closing tabs with middle click. (bxo#15687)
  - Translation updates
* Fri Oct 25 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Fix factory build failure
* Wed Jul  3 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.8.8
  - Do not show "Rewrap on resize" option for vte>=0.58: it's been
    deprecated, rewrapping on resize will always be enabled. (bxo#15562)
  - Drop support of Unicode encodings other than UTF-8 (bxo#15377)
  - Fix the size of drop-down window after it's been in fullscreen mode
    (bxo#15240)
  - Convert LF to CR when feeding text - this fixes pasting text to some
    apps (see https://gitlab.gnome.org/GNOME/vte/issues/106)
  - Save accelerators map on exit (bxo#15201)
  - Add support for the Tab key in shortcuts (by default, GTK doesn't
    allow that)
  - Do not resize the window when it's vertically maximized (bxo#10551)
  - Add action to switch to last active tab (bxo#15201)
  - Respect Xfce monospace font setting (bxo#15202)
  - Dropdown window was session saved and restored as a normal window if
    it was the only one (bxo#11362)
  - Preferences: Align controls on the General tab
  - Implement "Unsafe Paste" dialog (bxo#13252)
  - Enable Ctrl+(Shift)+Tab as Next/Prev Tab shortcuts (bxo#15092)
  - Add an option to use system theme colors for text and background
    (bxo#14808)
  - Search dialog improvements: Enable "Wrap around" by default; Make
    "Find Next"/"Find Previous" menu items respect search settings; Make
    buttons use menu item accelerators; Allow to set opacity (min 10%%)
    (bxo#15124)
  - Fix handling of OSC-10 escape sequence (bold text color) (bxo#15019)
  - Refine the wording for "opacity not available" (bxo#14904)
  - Add a space character after a dragged filename or URL (bxo#14849)
  - Support monitoring of the terminalrc file even it's a symlink
    (bxo#14698)
  - Fix the "Close tab" button: When the "Close tab" button got clicked in
    the "Confirm close" dialog, the entire window (instead of just the
    current tab) got closed (bxo#14645)
  - Preferences: remove dependency on libxfce4ui
  - Fix typo in the .desktop file (bxo#14594)
  - Improve .desktop files for GNOME (bxo#14575)
  - Fix a small typo in the manpage
  - JIT compile regexes (taken from gnome-terminal). This allows to
    recognize longer and more complex URLs.
  - Update terminal regexes from gnome-terminal (regex: Allow apostrophes
    in URLs, except when enclosed between them)
  - Allow to move tabs between windows by dragging them onto the terminal
    area
  - When detaching a tab from a drop-down window, resize the new window to
    the default geometry
  - Reset activity indicator for the active tab when focusing window
  - Distinguish terminal settings from the actual terminal entry in the
    menu (bxo#14456)
  - When closing an active tab, switch to the previously active one
  - Tab title color feature improvements: add action, restore the color
    when unclosing a tab, fix the color picker dialog's name, add Reset
    button
  - Some parts of the --help output were not translated
  - Restore terminal colors when unclosing a tab
  - Translation updates
- Cleaned up spec file
- Added bcond to build with git master sources
* Tue Feb 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fix issue with xfce4-terminal-settings.desktop entries boo#1125146
- Dropped obsolete macros
- Added %%license macro
* Wed May 16 2018 seife+obs@b1-systems.com
- update to version 0.8.7.4
  - Tab became active if unclosed to the left of the current tab
  - Fix new tab being one pixel short under some GTK themes (e.g.
    Greybird) which led to changing the window geometry and losing
    a row (bxo#13263)
  - Resolve deprecation of vte_terminal_match_set_cursor_type()
  - Add --preferences command line option and corresponding .desktop
    file: this allows to open a standalone Preferences dialog from
    Xfce Settings (bxo#13249)
  - Add command line options for setting text (foreground) and
    background colors: --color-text and --color-bg (bxo#4887)
  - Add "Copy Input" action: it shows a popover and allows to copy
    the input to all tabs within the current window (bxo#10047)
  - Update URLs to use https protocol
  - Add info on accels.scm to the man page
  - Reduce the Preferences dialog height
  - First show the terminal and then update its settings (bxo#14322)
  - Add command line option --active-tab which allows to specify
    active tab within a window. It also allows to keep the active tab
    when restoring a saved Xfce session.
  - Convert "Relaunch" dialog to GtkInfoBar to make it less intrusive
  - Add tooltips for "Set Title" popover elements
  - Resolve the warnings gcc8 has introduced
  - Translation updates
- changes in 0.8.7.3
  - Fix drop-down terminal hotkey (bxo#14289)
  - Suppress gdk_keyboard_(un)grab deprecation warnings
  - Restore "Allow bold text" option (bxo#14292)
  - Fix app crash when running a non-existing command (bxo#14295)
  - Correct foreground process check for async child spawn
  - Add an option to disable "Relaunch" dialog pop-up (bxo#14287)
- changes in 0.8.7.2
  - Fix gdk_keyboard_(un)grab deprecation warnings
  - Suppress gtk_status_icon_* deprecation warnings
  - Use async spawn method for VTE >= 0.48 (bxo#14249)
  - Fix handling of tabs reordering (bxo#14278)
  - Update window actions and active tab indication on reordering tabs
* Wed May 16 2018 bosim@opensuse.org
- update to version 0.8.7.1:
  * Fix Alt+n shortcuts for switching tabs; also, update tabs menu after
    reordering tabs (bxo#14247, boo#1092655)
* Fri Mar  2 2018 seife+obs@b1-systems.com
- update to version 0.8.7:
  * Update man page: add a note about config file changes being
    picked up
  * Update 'Read-Only' checkbox state when switching between tabs
  * Use Ctrl+click to directly open color editor in Preferences (bxo#13715)
  * Add a setting to control drop-down window vertical position (bxo#13722)
  * Allow per-terminal configuration of 'scroll on output' mode
  * Add "Copy as HTML" to Edit and context menus (VTE 0.50 required)
  * Add support for utmp file updates (build using --with-utempter
    parameter) (bxo#13710)
  * Fix negative geometry offsets handling (bxo#13753)
  * Focus the terminal after closing Set Title popover (bxo#13754)
  * Request confirmation when closing window or tab which has a
    running process (bxo#13781)
  * Add an option to open new tab to the right of the current tab (bxo#13821)
  * Fix VTE critical message when a terminal has no pty
  * Allow to restart a process after it exited or was killed
    (for -H/--hold) (bxo#13820)
  * Expose default terminal directory setting to Preferences: if
    set, will be used by new terminals; current directory will be
    used otherwise. MiscDefaultWorkingDir renamed to DefaultWorkingDir.
  * Make use of VTE 0.52 new vte_terminal_get_scroll_on_output() API
  * Add new tab to the currently active window, not to the last open (bxo#13891)
  * Move slim tabs setting to the Appearance tab
  * Add Audible and Visual bells configuration to Preferences (bxo#13874)
  * Disable move tab actions when MiscCycleTabs is false and the tab
    is in the  leftmost or rightmost position (bxo#13892)
  * Try to retrieve current working directory from VTE (bxo#13902)
  * Fix BSD build by adding missing include
  * Bump required GTK+ version to 3.20.8 to resolve the problem with
    Set Title dialog that is using GtkPopover (bxo#13996)
  * Do not escape URL as libxfce4ui now does it (bxo#12715)
  * Expose "middle mouse click to open URLs" setting to Preferences
  * Fix handling empty $DISPLAY env var which may happen under
    Wayland (bxo#14092)
  * Update regex definitions from gnome-terminal: Disallow terminating
    semicolon in URLs, Allow balanced pairs of square brackets in URLs
  * Remove man page translation files as Transifex doesn't take care
    of them (bxo#12938)
  * Add option to control text blinking (VTE 0.51.3) (bxo#14127)
  * Add "Bold is bright" option; remove "Allow bold text" option
    (VTE 0.51.3)
  * Add cell spacing options (VTE 0.51.3) (bxo#14127)
  * Allow underscores that are part of tab titles to be shown in the
    tabs menu
  * Don't copy working directory to $PWD for vte >= 0.51.90
  * Resolve deprecations of GDK functions
  * Translation updates
- remove obsoleted 0001-Revert-Fix-handling-email-addresses.patch
* Mon Dec 11 2017 seife+obs@b1-systems.com
- add 0001-Revert-Fix-handling-email-addresses.patch (boo#1071961,
  bxo#14076) the "Fix handling email addresses" commit in 0.8.6
  actually broke email address handling.
* Wed Nov 22 2017 seife+obs@b1-systems.com
- Update to version 0.8.6:
  - Fix handling email addresses
  - Allow per-tab configuration of dynamic tytle mode and initial
    title by adding --dynamic-tytle-mode and --initial-title
    options (bxo#2908)
  - Migrate tab 'Set Title' dialog to a gtk popover (bxo#13522)
  - Add option to select cursor foreground (text) color
  - Fix drop-down terminal ignoring 'move to monitor with pointer'
    option (bxo#13666)
  - Disable Ctrl+PgUp/PgDn shortcuts with only one tab (bxo#10469)
  - Fix negative dimensions GTK warning when running terminal with
  - -tab option
  - Update regexes from gnome-terminal
  - Fix --tab option broken lately (bxo#13587)
  - Fix drop-down window positioning when using --zoom option
  - Translation updates
* Fri Jun 16 2017 sor.alexei@meowr.ru
- Update to version 0.8.5.1:
  * Fix font settings load (bxo#13574).
* Sat May 20 2017 lazy.kent@opensuse.org
- Update to 0.8.5.
  * Do not change drop-down window size when zooming in/out.
  * Create terminal of desired size instead of default size of
    80x24: this allows to avoid resizing the terminal right after
    creation.
  * Use default terminal geometry when --geometry parameter is used
    but its value only contains X and Y offsets.
  * Improve label layout in preferences dialog: restrict max width
    to 80 chars.
  * Add --minimize command line option.
  * Calculate screen dimensions properly when having multiple
    monitors.
  * Prevent clipboard from being filled with garbage.
  * Resolve deprecation warnings: gtk_show_uri_on_window,
    gdk_screen_make_display_name, gdk_screen_get_width/height.
  * Silence most of deprecation warnings that are not resolved.
  * Make Preferences dialog app-global - the same dialog window
    will be used by multiple terminal windows.
  * Remove large space to the left of tab text when the text is too
    short (this allows tabs to be smaller).
  * Gtk3 required version bumped to 3.16.0.
  * Fix memory leaks.
  * Close Find dialog when closing parent terminal window.
  * Close Set Title dialog when closing its corresponding tab.
  * Translation updates: Catalan, Chinese (Taiwan), German, Greek,
    Hebrew, Kazakh, Lithuanian, Norwegian Bokmål, Polish,
    Portuguese (Brasil), Russian, Serbian, Slovenian, Swedish,
    Thai, Ukrainian.
- Changes in 0.8.4.
  * Fixes related to fullscreen state and showing/hiding window in
    drop-down mode.
  * Fix incorrect window positioning when started in fullscreen
    state.
  * Add a separate Show window borders setting for drop-down mode.
  * Make Double click chars setting more compact in the UI.
  * Do not force show drop-down window on screen size change.
  * Background image improvements: scale huge images to 8K when
    loading from file (this reduces memory consumption); print a
    warning if failed to open an image.
  * Expose Slim tabs setting to Preferences.
  * Translation updates: Bulgarian, Chinese (China), Chinese
    (Taiwan), Croatian, Czech, Danish, Dutch, Finnish, French,
    Japanese, Kazakh, Korean, Lithuanian, Malay, Norwegian Bokmål,
    Polish, Portuguese, Russian, Slovak, Spanish, Ukrainian.
* Wed Jan 25 2017 lazy.kent@opensuse.org
- Update to 0.8.3.
  * Fix incorrect initial position of a drop-down window under
    Unity.
  * min-height/width CSS properties not available in old GTK
    versions.
  * Remove redundant set_window_geometry_hints() call.
  * Add Help button to Set Title dialog.
  * GtkColorButton show-editor property only available starting
    with GTK 3.20.
  * Watch for screen size changes to update drop-down window size
    or position accordingly. Size change signal is emitted when
    monitor resolution is changed or another monitor is connected.
  * Make slim tabs even more slim.
  * Translation updates: Chinese (China), Lithuanian, Thai.
- Changes in 0.8.2.
  * Add hidden option MiscSlimTabs to override huge gtk3 tabs
    style.
  * Temporarily show menubar with F10 even if it's hidden.
  * Add "Run custom command instead of shell" feature.
  * Fix segfault on dragging last window tab to another window.
  * Add option for ambigouos-width characters (narrow/wide).
  * Don't show palette when editing palette colors in preferences.
  * Fix move dropdown window to monitor with pointer behavior.
  * When un-closing a tab, set it active if it was active when it
    got closed.
  * Set locale as vte encoding in case encoding is not set in prefs
    (support for running 'LANG=charset xfce4-terminal').
  * Allow to specify text selection background color.
  * Allow to select system-wide monospace font in preferences.
  * Fix Alt+n shortcuts when starting with several tabs.
  * Add option to automatically copy selection to the clipboard.
  * Support background image transparency.
  * Fix deprecation warnings.
  * Support setting drop-down status bar icon with --icon option.
  * Fix terminal geometry hints for GTK < 3.19.5.
  * Translation updates: Arabic, Bulgarian, Catalan, Chinese
    (China), Chinese (Taiwan), Croatian, Czech, Danish, Deutsch,
    Dutch, French, Hebrew, Italian, Japanese, Kazakh, Korean,
    Lithuanian, Malay, Norwegian Bokmål, Polish, Portuguese,
    Portuguese (Brazil), Russian, Slovak, Spanish, Swedish,
    Ukrainian.
* Fri Nov  4 2016 lazy.kent@opensuse.org
- Update to 0.8.1.
  * Fix Ctrl press recognition for opening URIs with Ctrl+click.
  * Set preferences dialog type hint to make it show on top.
  * Fix toggling fullscreen mode with F11 for a drop-down window.
  * Allow setting of empty shortcut for goto-tab actions.
  * Resolve window manager warning: Buggy client sent a
    _NET_ACTIVE_WINDOW message with a timestamp of 0.
  * Fix drop-down window visibility check.
  * Resolve some deprecation warnings.
  * Fix drop-down window not shown on different workspaces.
  * Add MiscUseShiftArrowsToScroll hidden option to allow
    Shift+arrows one-line scroll (off by default).
  * Allow user-defined color palettes - should be located under
    ~/.config/xfce4/terminal/colorschemes/.
  * Set window hints properly; show columns/rows when resizing.
  * Translation updates: Chinese (China), Croatian, English
    (Australia), French, Kazakh, Lithuanian, Malay, Polish,
    Spanish, Ukrainian.
* Sun Oct 23 2016 lazy.kent@opensuse.org
- Update to 0.8.0.
  * Move context menu zoom actions to a sub-menu.
  * Fix some build-time deprecation warnings.
  * Fix hiding of dropdown terminal.
  * Fix setting focus to dropdown window.
  * Fix "Always keep window on top" setting that was ignored.
  * Show missing action icons in dropdown mode.
  * Add rewrap on resize control option to Preferences.
  * Add --show/hide-scrollbar command line options.
  * Implement background image support; add BackgroundImageShading
    setting for background image mode.
  * Remove "Scrolling single line" option as the functionality is
    implemented by vte.
  * Add mouse-wheel binding for zoom: Shift + Ctrl + wheel up/down
    controlled by a hidden option MiscMouseWheelZoom - ON by
    default.
  * Do not set DISPLAY variable in non-X11 environments (e.g.
    Wayland).
  * Fix memory leak when showing preferences dialog.
  * Fix menubar text not visible with some themes.
  * Fix vte "resize-window" signal handler.
  * Fix notebook widget transparency seen under Unity.
  * Make vte transparency work in Gnome under both X11 and Wayland.
  * Show warning and disable Opacity control in Preferences if
    window manager does not support compositing.
  * Fix tab activity indication.
  * Fix geometry positioning when a negative offset is used.
  * Quote all file names/URIs drag-and-dropped to the terminal.
  * Fix cursor focus.
  * Translation updates: Bulgarian, Chinese (Taiwan), Croatian,
    Czech, Dutch, English (Australia), French, German, Hebrew,
    Japanese, Korean, Lithuanian, Malay, Polish, Portuguese,
    Portuguese (Brazil), Russian, Slovak, Spanish, Swedish, Thai,
    Ukrainian.
* Tue Oct 11 2016 lazy.kent@opensuse.org
- Update to 0.6.92.
  * Fix geometry setting (default ot provided via the command line
    option) for GTK 3.20.5.
  * Remove "Update utmp/wtmp records when command is launched"
    setting since the feature has been removed from vte.
  * Replace deprecated GtkTable with GtkGrid in Preferences.
  * Disable Zoom-In/Out actions on reaching zoom limits.
  * Do not allow Reset in Read-Only mode.
- Changes in 0.6.91.
  * Fix solarized light theme colors.
  * Fix huge size of Set Title dialog under wayland.
  * Support wayland (resolve crashes and warnings).
  * Improve handling negative x/y geometry positions.
  * Fix scrollbar/menubar/toolbar incorrectly shown in dropdown
    mode after window has been minimized/restored.
  * Add ability to save terminal contents to a file.
  * Prepare for upcoming vte regex API change.
  * Fix Vte-WARNING related to regex.
  * Implement Read-Only mode (user input disabled).
  * Fix input focus lost issue after exiting a console app (e.g.
    nano).
  * Fix cursor not blinking when fg color = bg color.
  * Enable configuration of a new tab working directory:
    MiscDefaultWorkingDir option. If it is set (non-empty value),
    new tabs and windows will use the dir specified as their
    working dir. Otherwise, the behavior remains as is (current dir
    will be used).
  * Do not un-close tab that was moved to another window.
  * Properly enable/disable F1 shortcut.
  * Fix Preferences window hidden in fullscreen mode.
  * Do not un-close tab that was detached to create another window.
  * Fix incorrect update of go-to-tab menu.
  * Add Undo Close Tab functionality: stores closed tabs in
    chronological order; restores working directory, position in
    the tabbar, custom title.
  * Add Close Other Tabs functionality.
  * Make terminal always drop down from the top of the screen.
  * Create Alt+digit shortcuts if they haven't been loaded from
    config file.
  * Fix dropdown window animation; remove viewport widget.
  * Code cleanup: Do not declare or define a reserved identifier.
  * Add urgent bell functionality: MiscBellUrgent option.
  * When detaching a tab, make new window respect original
    geometry.
  * Fix possible buffer overwrite issue.
  * Keep rows number constant when adding/removing widgets such as
    toolbar or tabbar.
  * Make a tab close button icon a bit smaller.
  * Add ability to switch tabs with a mouse scroll wheel.
  * Fix selection characters override.
  * Fix resize logic with tab.
  * Translation updates: Bulgarian, Catalan, Chinese (China),
    Chinese (Taiwan), Croatian, Czech, Dutch, English (Australia),
    German, Hebrew, Japanese, Korean, Portuguese (Brazil), Russian,
    Serbian, Spanish, Swedish, Turkish, Ukrainian.
* Wed Aug 10 2016 lazy.kent@opensuse.org
- Update to 0.6.90.
  * Migrate to GTK+3/VTE3.
  * Fix closing wrong tabs with Ctrl+Shift+W.
  * Make close tab shortcut work for single tab.
  * Add Ctrl+Shift+PgUp/PgDn shortcuts to move tabs left/right.
  * Add support for unlimited scrollback.
  * Fix actions applied to wrong tab after closing another one.
  * Update intltool.
  * Add Ctrl+Shift+S hotkey to set title.
  * Expose MiscTabCloseMiddleClick option to Preferences.
  * Fix terminal window not moved to foreground when using --tab
    option.
  * Respect Display window borders setting in drop-down mode.
  * Apply opacity setting by chaging background color alpha value.
  * Prevent characters from being hidden by block cursor.
  * Fix in drop-down mode, "100%% width" isn't really 100%%.
  * Add ShortcutsNoHelpkey option to disable F1 (help) shortcut key
    and expose it to Preferences.
  * Add support for magnet links.
  * Expose MiscMouseAutohide option to Preferences.
  * Fix terminal crash when starting with --geometry.
  * Add ability to zoom in/out by pressing Ctrl +/-; add --font and
  - -zoom command line options.
  * Expand zoom level.
  * Add hidden option MiscMiddleClickOpensUri to control whether
    middle click opens URI: if FALSE, Ctrl + left click is used for
    that; default is FALSE.
  * Fix compilation for vte < 0.44.
  * Remove emulation setting and input methods menu as they are not
    supported by vte.
  * Do not allow creating multiple Set Title dialog windows.
  * Remove Help button and add icon to Close button in Set Title
    dialog.
  * Add an icon to the search dialog close button.
  * Rename UI setting from Transparency to Opacity.
  * Update terminal website address in the About dialog.
  * Fix crash on moving a tab from one window to another.
  * Add tooltip for the Find toolbar button.
  * Add setting to allow cursor blinking to Preferences.
  * Add setting to change cursor shape to Preferences.
  * Fix typo in the preferences dialog.
  * Add some new encodings taken from gnome-terminal.
  * Fix crash on setting encoding.
  * Fix detach tab functionality with GTK>=3.16.
  * Fix segfault when right/middle click on tab bar.
  * Translation updates: Arabic, Asturian, Bulgarian, Catalan,
    Chinese (China), Chinese (Taiwan), Croatian, Czech, Danish,
    Dutch, English (Australia), Esperanto, Finnish, French, German,
    Greek, Hebrew, Hungarian, Icelandic, Indonesian, Italian,
    Japanese, Kazakh, Korean, Lithuanian, Malay, Norwegian Bokmål,
    Polish, Portuguese, Portuguese (Brazil), Romanian, Russian,
    Serbian, Slovak, Slovenian, Spanish, Swedish, Thai, Turkish,
    Ukrainian.
- Change BuildRequires: pkgconfig(gtk+-3.0), pkgconfig(vte-2.91).
- Remove BuildRequires: fdupes, update-desktop-files.
- Don't install ChangeLog (it is useless).
- Clean up the spec.
* Fri Dec 27 2013 gber@opensuse.org
- update to version 0.6.3
  - improve URL matching (bxo#7959, bxo#9800)
  - fix encoding menu creation (bxo#10395)
  - added light solarized colorscheme (bxo#10286)
  - fixed wrong foreground color in solarized dark (bxo#10285)
  - fix terminal session restore (bxo#9732)
  - translation updates
- drop obsolete
  xfce4-terminal-fix-up-the-encoding-menu-creation.patch
* Wed Oct 23 2013 lazy.kent@opensuse.org
-  Add xfce4-terminal-fix-up-the-encoding-menu-creation.patch: Fix
  up the encoding menu creation (bxo#10395).
* Sun May  5 2013 gber@opensuse.org
- update to version 0.6.2:
  - autotools updates
  - fix toolbars -> toolbar in docs
  - check display for the real display, not display.screen
  - display checking on drop-down windows
  - fix format warning
  - only call g_type_init on glib < 2.36
  - translation updates
* Mon Mar 11 2013 coolo@suse.com
- also obsolete Terminal-doc or you get an error on update
* Tue Jan  1 2013 gber@opensuse.org
- update to version 0.6.1:
  - add drop-down window support with --drop-down parameter, this
    allows xfce4-terminal to start 1 game-console like window
  - rename Go menu to Tabs
  - load default Alt+N accelerators on first startup
  - make single tab accelerator insensitive again
  - rename clear scrollbar to reset
  - fix crash when showing toolbar 2nd time
  - don't check for version and help in parameters parsing
  - remove Report Bug menu entry
  - hide search dialog on delete to avoid crash
  - set minimum tab label size to 10 chars
  - make right-click tab menu more functional
  - stop activity timeout when destroying a screen
  - rename $TERM to emulation and use new preference to avoid
    migration crashes
  - fix the tab re-use option when running from shortcut
  - allow underscore and + in email address
  - use new GPL license address
  - allow setting the geometry in the preferences
  - translation updates
* Fri Dec 28 2012 gber@opensuse.org
- provide/obsolete Terminal-lang correctly
* Fri Dec 28 2012 gber@opensuse.org
- Terminal was renamed to xfce4-terminal
